# GiaChat CLI
![GigaChat CLI Screenshot](https://gitverse.ru/api/repos/THEChrismoth/GigaChat-Cli/raw/branch/asset/gigachat_menu.jpg)

GiaChat CLI — это AI-агент с открытым исходным кодом, который позволит вам использовать возможности GiaChat прямо в вашем терминале. Он обеспечивает лёгкий доступ к GiaChat, предоставляя вам самый прямой путь от вашего запроса к нашей модели.

## 📦 Installation

### Установка из исходного кода

Клонируйте репозиторий

```
git clone https://gitverse.ru/THEChrismoth/GigaChat_Cli.git
cd gigachat_cli
```
Установите пакет

```
pip install gigachat-cli==0.1.0
```
## 🔐 Authentication Options

### GigaChat API Key
```
# Get your key from https://developers.sber.ru/studio/login
export GIGACHAT_API_KEY="YOUR_API_KEY"
gigachat
```
## 🚀 Getting Started

### Basic Usage

Запустите в конкретной дирректории 

```
gigachat
```
![GigaChat CLI Screenshot](https://gitverse.ru/api/repos/THEChrismoth/GigaChat-Cli/raw/branch/asset/gigachat_work.jpg)
